@@ -4,10 +4,14 @@ use fuel_types::Word;
 use strum_macros::EnumString;
 
 pub mod abi_decoder;
-#[cfg(not(feature = "no-std"))]
 pub mod abi_encoder;
+pub mod code_gen;
 pub mod errors;
-pub mod signature;
+pub mod json_abi;
+pub mod rustfmt;
+pub mod source;
+pub mod types;
+pub mod utils;
 
 pub type ByteArray = [u8; 8];
 pub type Selector = ByteArray;
